@@ -958,15 +958,15 @@ class Askdata(SignUp):
         return df.merge(df_query, how, on, left_on, right_on)
 
     def load_dataset(self, workspace_slug, dataset_slug):
-        all_fields = self.get_columns(workspace_slug, dataset_slug)["code"]
+        all_fields = list(self.get_columns(workspace=workspace_slug, dataset=dataset_slug)["code"])
         limit = 1000
-        df = self.query(workspace_slug, dataset_slug, all_fields, limit=limit)
+        df = self.query(workspace=workspace_slug, dataset=dataset_slug, fields=all_fields, limit=limit)
         if(len(df.index) < 1000):
             return df
         else:
             final_df = df
             while(len(df.index) == 1000):
-                df = self.query(workspace_slug, dataset_slug, all_fields, limit=(limit+1000), offset=limit)
+                df = self.query(workspace=workspace_slug, dataset=dataset_slug, fields=all_fields, limit=(limit+1000), offset=limit)
                 final_df = final_df.append(df)
             return final_df
 
