@@ -53,6 +53,32 @@ class Insight_Definition:
             self.app_url = "https://app.askdata.com"
 
 
+    def add_skin(self, skin_code:str):
+        body = {
+
+            "name": self.name,
+            "slug": self.slug,
+            "ui": {
+                "skin": skin_code
+            }
+        }
+
+        url = self.smart_insight_url+"/definitions/"+self.definition_id
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+
+        r = s.put(url=url, json=body, headers=headers)
+        r.raise_for_status()
+        self.components = r.json()["components"]
+
     def add_widget(self, widget_type: str, query_ids:list=[], settings:dict={}, values:dict={}, texts:dict={}, charts:list=[]):
         position = (len(self.components))
         widget_id = self.__create_widget(position, widget_type)
@@ -128,7 +154,7 @@ class Insight_Definition:
             "Content-Type": "application/json",
             "Authorization": "Bearer" + " " + self._token
         }
-        #logging.info("URL {}".format(url))
+
         r = s.post(url=url, json=body, headers=headers)
         r.raise_for_status()
         return r.json()
@@ -239,7 +265,6 @@ class Insight_Definition:
             "Authorization": "Bearer" + " " + self._token
         }
         query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'
-        #logging.info("URL {}".format(query_url))
         r = s.post(url=query_url, json=body, headers=headers)
         r.raise_for_status()
         self.components = r.json()["components"]
@@ -404,7 +429,6 @@ class Insight_Definition:
             "queryComponent":False
         }
 
-        #logging.info("URL: {}".format(url))
 
         s = requests.Session()
         s.keep_alive = False
