@@ -93,13 +93,13 @@ def read(type, settings):
 
 
 def __read_csv(settings: dict):
-    df = pd.read_csv(filepath_or_buffer=settings["path"], sep=settings["separator"], encoding=settings["encoding"])
+    df = pd.read_csv(filepath_or_buffer=settings["path"], sep=settings["separator"], encoding=settings["encoding"], parse_dates=[i for i in range(len(pd.read_csv(filepath_or_buffer=settings["path"], sep=settings["separator"], encoding=settings["encoding"]).columns))])
     df = normalize_columns(df)
     df.to_parquet(settings["parquet"])
 
 
 def __read_excel(settings: dict):
-    df = pd.read_excel(settings["path"])
+    df = pd.read_excel(settings["path"], parse_dates=[i for i in range(len(pd.read_excel(settings["path"])))])
     df = normalize_columns(df)
     df.to_parquet(settings["parquet"])
 
